""" Version module. """

#  ISC License
#
#  Copyright (c) 2020–2021, Paul Wilhelm, M. Sc. <anfrage@paulwilhelm.de>
#
#  Permission to use, copy, modify, and/or distribute this software for any
#  purpose with or without fee is hereby granted, provided that the above
#  copyright notice and this permission notice appear in all copies.
#
#  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
#  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
#  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
#  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
#  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
#  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.


__VERSION__ = "v1.10.2"


__URL__ = "https://github.com/shredEngineer/MagnetiCalc"
__VERSION__URL__ = "https://raw.githubusercontent.com/shredEngineer/MagnetiCalc/master/magneticalc/Version.py"


class Version:
    """ Version class. """

    # Full application version string
    String = "MagnetiCalc " + __VERSION__
    Copyright = "Copyright © 2020–2021, Paul Wilhelm, M. Sc. <mailto:anfrage@paulwilhelm.de>"
    License = "ISC License (see README.md)"
